Pos
===

.. currentmodule:: toasty.pyramid

.. autoclass:: Pos
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Pos.n
      ~Pos.x
      ~Pos.y

   .. rubric:: Attributes Documentation

   .. autoattribute:: n
   .. autoattribute:: x
   .. autoattribute:: y
